#!/bin/csh -f

# Script to create MODIS 250 meter GeoTIFF images

# Set MRTSwath and IDL variables
set path = ($path /home/gumley/MRTSwath/bin)
setenv MRTDATADIR /home/gumley/MRTSwath/data
setenv LM_LICENSE_FILE '1700@license'
setenv IDL_STARTUP

# Check arguments
if ($#argv != 9) then
  echo "Usage: modis_crefl_reproject.csh \"
  echo "  REF1KM REFHKM REFQKM MOD03 BAND1 BAND2 BAND3 RES PRMFIL"
  echo "where"
  echo "REF1KM is the 1KM corrected reflectance HDF file"
  echo "REFHKM is the HKM corrected reflectance HDF file"
  echo "REFQKM is the QKM corrected reflectance HDF file"
  echo "MOD03  is the 1KM geolocation HDF file"
  echo "BAND1  is the MODIS band assigned to the red   channel (1-7)"
  echo "BAND2  is the MODIS band assigned to the green channel (1-7)"
  echo "BAND3  is the MODIS band assigned to the blue  channel (1-7)"
  echo "RES    is the output spatial resolution (meters)"
  echo "PRMFIL is the name of the projection parameter file"
  exit(1)
endif

# Get arguments
set REF1KM = $argv[1]
set REFHKM = $argv[2]
set REFQKM = $argv[3]
set MOD03  = $argv[4]
set BAND1  = $argv[5]
set BAND2  = $argv[6]
set BAND3  = $argv[7]
set RES    = $argv[8]
set PRMFIL = $argv[9]

# Get region name
set REGION = `basename $PRMFIL`
set REGION = $REGION:r

# Get input file base name
set BASE = `basename $REF1KM | cut -d. -f1-3`

# Reproject band 1: QKM input -> GeoTIFF output
echo "(Reprojecting 250 meter band 1)"
swath2grid -if=$REFQKM -gf=$MOD03 -of=$BASE.QKM_PROJ -off=GEOTIFF_FMT \
  -sds="CorrRefl_01" -opsz=$RES -pf=$PRMFIL
set QKM_PROJ = $BASE.QKM_PROJ_CorrRefl_01.tif

# Check if reprojection was successful
if ($status != 0) then
  echo "Error: Could not reproject this region"
  exit(1)
endif

# Set list of HKM SDS names to reproject (band 1 must be included)
if ($BAND1 != 1 && $BAND2 != 1 && $BAND3 != 1) then
  set SDS_NAMES = "CorrRefl_0"$BAND1";CorrRefl_0"$BAND2";CorrRefl_0"$BAND3";CorrRefl_01"
else
  set SDS_NAMES = "CorrRefl_0"$BAND1";CorrRefl_0"$BAND2";CorrRefl_0"$BAND3
endif

# Reproject R, G, B bands: HKM input -> HDF output
echo "(Reprojecting 500 meter bands)"
swath2grid -if=$REFHKM -gf=$MOD03 -of=$BASE.HKM_PROJ -off=HDF_FMT \
  -sds="$SDS_NAMES" -opsz=$RES -pf=$PRMFIL
set HKM_PROJ = $BASE.HKM_PROJ.hdf

# Set output TIFF filename
set OUT_TIFF = $BASE.$REGION.${BAND1}${BAND2}${BAND3}.${RES}m.tif

# Run IDL script to create sharpened QKM true color image
echo "(Creating output image)"
set SCRIPT = create_geotiff.pro
echo "\!path = \!path + ':/home/gumley/idl/src'" > $SCRIPT
echo "modis_crefl_geotiff, '"$QKM_PROJ"', '"$HKM_PROJ"', '"$OUT_TIFF"', bands=["$BAND1", "$BAND2", "$BAND3"]" >> $SCRIPT
echo "exit" >> $SCRIPT
/usr/local/bin/idl $SCRIPT
rm -f $SCRIPT
echo "(Created "$OUT_TIFF")"

# Clean up and exit
rm -f $QKM_PROJ $HKM_PROJ mrtswath.log 
rm -f patches.tmp* tmp?????? >& /dev/null
exit(0)
